@@ -5,14 +5,22 @@ from logging import Formatter, StreamHandler
 from logging.handlers import RotatingFileHandler
 import traceback
 import subprocess
+import getpass
 
+LOG_LEVEL_MAP = {
+    'DEBUG': logging.DEBUG,
+    'INFO': logging.INFO,
+    'WARNING': logging.WARNING,
+    'ERROR': logging.ERROR,
+    'CRITICAL': logging.CRITICAL
+}
 
 
 def init_logger(
     name = 'default_logger',
     log_path = '/var/log/slg/default_location.log',
-    log_level = logging.INFO,
-    stream_log_level = logging.DEBUG,
+    log_level = 'INFO',
+    stream_log_level = 'DEBUG',
     formatter_str = '%(asctime)s | %(levelname)-8s | Line %(lineno)-4s | %(pathname)s | %(message)s',
     max_bytes=10000000,
     backup_count=5
@@ -22,6 +30,9 @@ def init_logger(
 
     It's also advised to set the log_path to "/var/log/slg/{__file__.split("/")[-1]}.log" when calling from a script so you don't log to a default file but also one relevant to the script.
     '''
+    log_level = LOG_LEVEL_MAP[log_level]
+    stream_log_level = LOG_LEVEL_MAP[stream_log_level]
+
     def find_existing_dir(directory_path):
         '''Finds the lowest directory that actually exists, to check if we have write access to said dir'''
         if os.path.isdir(directory_path):
@@ -41,8 +52,8 @@ def init_logger(
             subprocess.run(f'mkdir -p {write_directory}', shell=True)
         else:
             username = input('The write directory does not exist and is write-protected, please enter the username this directory should belong to: ')
-            password = input('Now please enter the sudo password so we can create the directory in write protected directory: ')
-            subprocess.run(f'echo {password} | sudo -S -u {username} mkdir -p {write_directory}', shell=True)
+            password = getpass.getpass('Now please enter the sudo password so we can create the directory in write protected directory: ')
+            subprocess.run(f'echo {password} | sudo -S mkdir -p {write_directory} 2>&1 /dev/null && echo {password} | sudo -S chown -R {username}:{username} {write_directory} 2>&1 /dev/null', shell=True)
 
     try:
         logger = logging.getLogger(name)
